/**************************************************************************
/* This class is the main driver class for the guiwidgets demo.
/*
/* Copyright (c) 2006 by Bernhard Bablok (mail@bablokb.de)
/*
/* This program is free software; you can redistribute it and/or modify
/* it under the terms of the GNU General Public License as published
/* by  the Free Software Foundation; either version 2 of the License or
/* (at your option) any later version.
/*
/* This program is distributed in the hope that it will be useful, but
/* WITHOUT ANY WARRANTY; without even the implied warranty of
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
/* GNU General Public License for more details.
/*
/* You should have received a copy of the GNU General Public License
/* along with this program; see the file COPYING.  If not, write to
/* the Free Software Foundation Inc., 59 Temple Place - Suite 330,
/* Boston, MA  02111-1307 USA
/**************************************************************************/

import java.io.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

import com.greef.ui.calendar.*;
import com.l2fprod.common.swing.*;
import org.netbeans.api.wizard.*;
import org.netbeans.spi.wizard.*;
 
/**
   This class is the main driver class for the guiwidgets demo.

   @version $Revision: 1.4 $
   @author  $Author: bablokb $
*/

public class Main extends JFrame {

  //////////////////////////////////////////////////////////////////////////////

  /**
     Constructor.
  */

  public Main() {
    super("GUI-Widget Demo");
    getContentPane().setLayout(new BorderLayout());
    getContentPane().add("Center",getButtonBar());
    setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
    pack();
    setLocation(100, 100);
    setVisible(true);
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create ButtonBar
  */

  private JPanel getButtonBar() {
    ButtonBarPanel bbp = new ButtonBarPanel();
    bbp.addPanel(getCalendarPanel(),"calendar","calendar.png");
    bbp.addPanel(getDirChooserPanel(),"directory","directory.png");
    bbp.addPanel(getFontChooserPanel(),"fonts","fonts.png");
    bbp.addPanel(getWizardPanel(),"wizard","wizard.png");
    return bbp;
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create a calendar with a jcalendar-widget.
  */

  private JPanel getCalendarPanel() {
    JCalendar cal = new JCalendar();
    return new WidgetPanel("A Calendar-Widget",cal);
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create a panel with a button which triggers the directory-chooser.
  */

  private JPanel getDirChooserPanel() {
    JButton button =  new JButton("Select Directory...",
                                                new ImageIcon("directory.png"));
    button.addActionListener(new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	  doSelectDir();
	}});
    return new WidgetPanel("Choose Directory",button);
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Show the JDirectoryChooser.
  */

  private void doSelectDir() {
    JDirectoryChooser dirChooser = new JDirectoryChooser();
    dirChooser.setMultiSelectionEnabled(true);
    int choice = dirChooser.showOpenDialog(this);
    if (choice == JDirectoryChooser.APPROVE_OPTION) {
      StringBuffer filenames = new StringBuffer();
      File[] selectedFiles = dirChooser.getSelectedFiles();
      for (int i = 0; i<selectedFiles.length; i++) {
        filenames.append("\n");
        filenames.append(selectedFiles[i]);
      }
      JOptionPane.showMessageDialog(this,filenames);
    } else {
      JOptionPane.showMessageDialog(this,"selection cancelled");
    }
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create a panel with a button which triggers the font-chooser.
  */

  private JPanel getFontChooserPanel() {
    final JButton button =  new JButton("Select Font...",
                                                new ImageIcon("fonts.png"));
    button.addActionListener(new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	  doSelectFont(button);
	}});
    return new WidgetPanel("Select Font",button);
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Show the JFontChooser.
  */

  private void doSelectFont(Component parent) {
    Font selectedFont = JFontChooser.showDialog(parent,"Choose Font",null);
    if (selectedFont == null) {
      JOptionPane.showMessageDialog(parent,"selection cancelled");
    } else {
      JOptionPane.showMessageDialog(parent,"selected font: "
                                                       + selectedFont.getName());
    }
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Create a panel with a button which triggers a simple wizard.
  */

  private JPanel getWizardPanel() {
    JButton button =  new JButton("Run Wizard...",new ImageIcon("wizard.png"));
    final JTextArea area = new JTextArea();
    area.setBorder(BorderFactory.
      createTitledBorder(BorderFactory.createLineBorder(Color.BLUE),
                                                              "Wizard Result"));
    JPanel wizPanel = new JPanel();
    wizPanel.setLayout(new BorderLayout());
    wizPanel.add(button,BorderLayout.NORTH);
    wizPanel.add(area,BorderLayout.SOUTH);

    button.addActionListener(new ActionListener() {
	public void actionPerformed(ActionEvent e) {
	  doRunWizard(area);
	}});
    return new WidgetPanel("Run Wizard",wizPanel);
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Run Wizard
  */

  private void doRunWizard(final JTextArea area) {
    WizardPage[] panels = new WizardPage[] {
      new WizardPanel("Page 1",1),
      new WizardPanel("Page 2",2),
      new WizardPanel("Page 3",3)
    };

    WizardPage.WizardResultProducer resultCollector = 
      new WizardPage.WizardResultProducer() {
	public Object finish(Map wizardData) {
	  StringBuffer buf = new StringBuffer();
	  buf.append("EntryField1: ");
	  buf.append(wizardData.get("EntryField1"));
	  buf.append("\n");
	  buf.append("EntryField2: ");
	  buf.append(wizardData.get("EntryField2"));
	  buf.append("\n");
	  buf.append("EntryField3: ");
	  buf.append(wizardData.get("EntryField3"));
	  area.setText(buf.toString());
	  return area;
	}};
    WizardDisplayer.showWizard(WizardPage.createWizard(panels,resultCollector));
  }

  //////////////////////////////////////////////////////////////////////////////

  /**
     Main entry point.
  */

  public static void main(String[] args) {
    Main runner = new Main();
  }
}
